@@ -1,15 +1,19 @@
 from __future__ import division
 
 import math
+import os
 import os.path as osp
 from pathlib import Path
 import shutil
 import subprocess
+import tempfile
 from tempfile import NamedTemporaryFile
 
 import cv2
 import skvideo.io
 
+from pybsc.timestamp_utils import get_timestamp_indices_wrt_base
+
 
 def hhmmss_to_seconds(ts):
     try:
@@ -169,3 +173,48 @@ def count_frames(video_path, start=0.0, duration=-1,
             / int(math.ceil(fps * sampling_frequency))))
     else:
         return int(math.ceil(video_duration * fps))
+
+
+def video2fileframes(
+        video_path,
+        output_path=None,
+        filename_tmpl='img_{:05}.jpg'):
+    if output_path is None:
+        tmp_output_dir = tempfile.TemporaryDirectory()
+        tmp_output_dir.cleanup()
+        os.makedirs(tmp_output_dir.name, exist_ok=True)
+        output_path = tmp_output_dir.name
+    output_path = Path(output_path)
+    outfiles = []
+    timestamps = []
+    for i, (frame, stamp) in enumerate(
+            load_frame(video_path), 0):
+        outfile = output_path / filename_tmpl.format(i)
+        cv2.imwrite(str(outfile), frame)
+        outfiles.append(outfile)
+        timestamps.append(stamp)
+    return outfiles, timestamps
+
+
+def split_video_to_fileframe_from_sections(
+        outfiles, timestamps, start_stamps, end_stamps,
+        output_path=None,
+        filename_tmpl='img_{:05}.jpg',
+        dirname_tmpl='frames_{:05}-{:05}'):
+    if output_path is None:
+        tmp_output_dir = tempfile.TemporaryDirectory()
+        tmp_output_dir.cleanup()
+        os.makedirs(tmp_output_dir.name, exist_ok=True)
+        output_path = tmp_output_dir.name
+    output_path = Path(output_path)
+    output_frame_parent_paths = []
+    for start_stamp, end_stamp in zip(start_stamps, end_stamps):
+        start = get_timestamp_indices_wrt_base(timestamps, start_stamp)
+        end = get_timestamp_indices_wrt_base(timestamps, end_stamp)
+        frame_outpath = output_path / filename_tmpl.format(start, end)
+        os.makedirs(str(frame_outpath), exist_ok=True)
+        for i, filename in enumerate(outfiles[start:end]):
+            filename = Path(filename)
+            shutil.copy(filename, frame_outpath / filename_tmpl.format(i))
+        output_frame_parent_paths.append(frame_outpath)
+    return output_frame_parent_paths
